@@ -18,8 +18,8 @@
 package v2data
 
 import (
-	"github.com/IrineSistiana/mosdns/dispatcher/pkg/matcher/domain"
-	"github.com/IrineSistiana/mosdns/dispatcher/pkg/matcher/netlist"
+	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/matcher/domain"
+	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/matcher/netlist"
 )
 
 func init() {
